@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::FLORA::AUTHORITY = 'cpan:FLORA';
 }
 BEGIN {
-  $Dist::Zilla::PluginBundle::FLORA::VERSION = '0.07';
+  $Dist::Zilla::PluginBundle::FLORA::VERSION = '0.08';
 }
 # ABSTRACT: Build your distributions like FLORA does
 
@@ -45,6 +45,12 @@ method _build_is_task {
     return $self->dist =~ /^Task-/ ? 1 : 0;
 }
 
+has disable_pod_coverage_tests => (
+    is      => 'ro',
+    isa     => Bool,
+    default => 0,
+);
+
 has bugtracker_url => (
     isa     => Uri,
     coerce  => 1,
@@ -178,10 +184,12 @@ method configure {
         MetaJSON
         PkgVersion
         PodSyntaxTests
-        PodCoverageTests
         SanityTests
     ));
 
+    $self->add_plugins('PodCoverageTests')
+        unless $self->disable_pod_coverage_tests;
+
     $self->add_plugins(
         [MetaResources => {
             repository => $self->_repository_url,
